==> BlazeMeterJenkinsPlugin-2.5.2-sources.jar: hudson/plugins/blazemeter/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.blazemeter;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Responding time
     * 
     */
    public static String ProjectAction_RespondingTime() {
        return holder.format("ProjectAction.RespondingTime");
    }

    /**
     * Responding time
     * 
     */
    public static Localizable _ProjectAction_RespondingTime() {
        return new Localizable(holder, "ProjectAction.RespondingTime");
    }

    /**
     *  90% line
     * 
     */
    public static String ProjectAction_Line90() {
        return holder.format("ProjectAction.Line90");
    }

    /**
     *  90% line
     * 
     */
    public static Localizable _ProjectAction_Line90() {
        return new Localizable(holder, "ProjectAction.Line90");
    }

    /**
     * BlazeMeter report
     * 
     */
    public static String TrendReportDetail_DisplayName() {
        return holder.format("TrendReportDetail.DisplayName");
    }

    /**
     * BlazeMeter report
     * 
     */
    public static Localizable _TrendReportDetail_DisplayName() {
        return new Localizable(holder, "TrendReportDetail.DisplayName");
    }

    /**
     * Configure
     * 
     */
    public static String GraphConfigurationDetail_DisplayName() {
        return holder.format("GraphConfigurationDetail.DisplayName");
    }

    /**
     * Configure
     * 
     */
    public static Localizable _GraphConfigurationDetail_DisplayName() {
        return new Localizable(holder, "GraphConfigurationDetail.DisplayName");
    }

    /**
     * BlazeMeter
     * 
     */
    public static String Report_DisplayName() {
        return holder.format("Report.DisplayName");
    }

    /**
     * BlazeMeter
     * 
     */
    public static Localizable _Report_DisplayName() {
        return new Localizable(holder, "Report.DisplayName");
    }

    /**
     * max
     * 
     */
    public static String ProjectAction_Maximum() {
        return holder.format("ProjectAction.Maximum");
    }

    /**
     * max
     * 
     */
    public static Localizable _ProjectAction_Maximum() {
        return new Localizable(holder, "ProjectAction.Maximum");
    }

    /**
     * average
     * 
     */
    public static String ProjectAction_Average() {
        return holder.format("ProjectAction.Average");
    }

    /**
     * average
     * 
     */
    public static Localizable _ProjectAction_Average() {
        return new Localizable(holder, "ProjectAction.Average");
    }

    /**
     * errors
     * 
     */
    public static String ProjectAction_Errors() {
        return holder.format("ProjectAction.Errors");
    }

    /**
     * errors
     * 
     */
    public static Localizable _ProjectAction_Errors() {
        return new Localizable(holder, "ProjectAction.Errors");
    }

    /**
     * median
     * 
     */
    public static String ProjectAction_Median() {
        return holder.format("ProjectAction.Median");
    }

    /**
     * median
     * 
     */
    public static Localizable _ProjectAction_Median() {
        return new Localizable(holder, "ProjectAction.Median");
    }

    /**
     * min
     * 
     */
    public static String ProjectAction_Minimum() {
        return holder.format("ProjectAction.Minimum");
    }

    /**
     * min
     * 
     */
    public static Localizable _ProjectAction_Minimum() {
        return new Localizable(holder, "ProjectAction.Minimum");
    }

    /**
     * Percentage of errors
     * 
     */
    public static String ProjectAction_PercentageOfErrors() {
        return holder.format("ProjectAction.PercentageOfErrors");
    }

    /**
     * Percentage of errors
     * 
     */
    public static Localizable _ProjectAction_PercentageOfErrors() {
        return new Localizable(holder, "ProjectAction.PercentageOfErrors");
    }

    /**
     * BlazeMeter Testings - JMeter in the cloud
     * 
     */
    public static String Publisher_DisplayName() {
        return holder.format("Publisher.DisplayName");
    }

    /**
     * BlazeMeter Testings - JMeter in the cloud
     * 
     */
    public static Localizable _Publisher_DisplayName() {
        return new Localizable(holder, "Publisher.DisplayName");
    }

    /**
     * BlazeMeter API Key
     * 
     */
    public static String BlazemeterCredential_DisplayName() {
        return holder.format("BlazemeterCredential.DisplayName");
    }

    /**
     * BlazeMeter API Key
     * 
     */
    public static Localizable _BlazemeterCredential_DisplayName() {
        return new Localizable(holder, "BlazemeterCredential.DisplayName");
    }

    /**
     * BlazeMeter Trend
     * 
     */
    public static String ProjectAction_DisplayName() {
        return holder.format("ProjectAction.DisplayName");
    }

    /**
     * BlazeMeter Trend
     * 
     */
    public static Localizable _ProjectAction_DisplayName() {
        return new Localizable(holder, "ProjectAction.DisplayName");
    }

    /**
     * BlazeMeter Report
     * 
     */
    public static String BuildAction_DisplayName() {
        return holder.format("BuildAction.DisplayName");
    }

    /**
     * BlazeMeter Report
     * 
     */
    public static Localizable _BuildAction_DisplayName() {
        return new Localizable(holder, "BuildAction.DisplayName");
    }

}

==> BlazeMeterJenkinsPlugin-4.3-sources.jar: hudson/plugins/blazemeter/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.blazemeter;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Responding time
     * 
     */
    public static String ProjectAction_RespondingTime() {
        return holder.format("ProjectAction.RespondingTime");
    }

    /**
     * Responding time
     * 
     */
    public static Localizable _ProjectAction_RespondingTime() {
        return new Localizable(holder, "ProjectAction.RespondingTime");
    }

    /**
     *  90% line
     * 
     */
    public static String ProjectAction_Line90() {
        return holder.format("ProjectAction.Line90");
    }

    /**
     *  90% line
     * 
     */
    public static Localizable _ProjectAction_Line90() {
        return new Localizable(holder, "ProjectAction.Line90");
    }

    /**
     * BlazeMeter report
     * 
     */
    public static String TrendReportDetail_DisplayName() {
        return holder.format("TrendReportDetail.DisplayName");
    }

    /**
     * BlazeMeter report
     * 
     */
    public static Localizable _TrendReportDetail_DisplayName() {
        return new Localizable(holder, "TrendReportDetail.DisplayName");
    }

    /**
     * Configure
     * 
     */
    public static String GraphConfigurationDetail_DisplayName() {
        return holder.format("GraphConfigurationDetail.DisplayName");
    }

    /**
     * Configure
     * 
     */
    public static Localizable _GraphConfigurationDetail_DisplayName() {
        return new Localizable(holder, "GraphConfigurationDetail.DisplayName");
    }

    /**
     * BlazeMeter
     * 
     */
    public static String Report_DisplayName() {
        return holder.format("Report.DisplayName");
    }

    /**
     * BlazeMeter
     * 
     */
    public static Localizable _Report_DisplayName() {
        return new Localizable(holder, "Report.DisplayName");
    }

    /**
     * max
     * 
     */
    public static String ProjectAction_Maximum() {
        return holder.format("ProjectAction.Maximum");
    }

    /**
     * max
     * 
     */
    public static Localizable _ProjectAction_Maximum() {
        return new Localizable(holder, "ProjectAction.Maximum");
    }

    /**
     * average
     * 
     */
    public static String ProjectAction_Average() {
        return holder.format("ProjectAction.Average");
    }

    /**
     * average
     * 
     */
    public static Localizable _ProjectAction_Average() {
        return new Localizable(holder, "ProjectAction.Average");
    }

    /**
     * errors
     * 
     */
    public static String ProjectAction_Errors() {
        return holder.format("ProjectAction.Errors");
    }

    /**
     * errors
     * 
     */
    public static Localizable _ProjectAction_Errors() {
        return new Localizable(holder, "ProjectAction.Errors");
    }

    /**
     * median
     * 
     */
    public static String ProjectAction_Median() {
        return holder.format("ProjectAction.Median");
    }

    /**
     * median
     * 
     */
    public static Localizable _ProjectAction_Median() {
        return new Localizable(holder, "ProjectAction.Median");
    }

    /**
     * BlazeMeter Legacy Credentials(DEPRECATED)
     * 
     */
    public static String BlazemeterLegacyCredential_DisplayName() {
        return holder.format("BlazemeterLegacyCredential.DisplayName");
    }

    /**
     * BlazeMeter Legacy Credentials(DEPRECATED)
     * 
     */
    public static Localizable _BlazemeterLegacyCredential_DisplayName() {
        return new Localizable(holder, "BlazemeterLegacyCredential.DisplayName");
    }

    /**
     * min
     * 
     */
    public static String ProjectAction_Minimum() {
        return holder.format("ProjectAction.Minimum");
    }

    /**
     * min
     * 
     */
    public static Localizable _ProjectAction_Minimum() {
        return new Localizable(holder, "ProjectAction.Minimum");
    }

    /**
     * Percentage of errors
     * 
     */
    public static String ProjectAction_PercentageOfErrors() {
        return holder.format("ProjectAction.PercentageOfErrors");
    }

    /**
     * Percentage of errors
     * 
     */
    public static Localizable _ProjectAction_PercentageOfErrors() {
        return new Localizable(holder, "ProjectAction.PercentageOfErrors");
    }

    /**
     * BlazeMeter Testings - JMeter in the cloud
     * 
     */
    public static String Publisher_DisplayName() {
        return holder.format("Publisher.DisplayName");
    }

    /**
     * BlazeMeter Testings - JMeter in the cloud
     * 
     */
    public static Localizable _Publisher_DisplayName() {
        return new Localizable(holder, "Publisher.DisplayName");
    }

    /**
     * BlazeMeter Credentials
     * 
     */
    public static String BlazemeterCredential_DisplayName() {
        return holder.format("BlazemeterCredential.DisplayName");
    }

    /**
     * BlazeMeter Credentials
     * 
     */
    public static Localizable _BlazemeterCredential_DisplayName() {
        return new Localizable(holder, "BlazemeterCredential.DisplayName");
    }

    /**
     * BlazeMeter Trend
     * 
     */
    public static String ProjectAction_DisplayName() {
        return holder.format("ProjectAction.DisplayName");
    }

    /**
     * BlazeMeter Trend
     * 
     */
    public static Localizable _ProjectAction_DisplayName() {
        return new Localizable(holder, "ProjectAction.DisplayName");
    }

    /**
     * BlazeMeter Report
     * 
     */
    public static String BuildAction_DisplayName() {
        return holder.format("BuildAction.DisplayName");
    }

    /**
     * BlazeMeter Report
     * 
     */
    public static Localizable _BuildAction_DisplayName() {
        return new Localizable(holder, "BuildAction.DisplayName");
    }

}
